#suppose the $1.seq is in the current directory
#   1, we need to run PSIBLAST to generate the psp file
#   2, run PSIPRED to generate the ss file, and run newss.sh to tranform 
#          the column ss into row representation
#   3, run HHPRED to generate the hmm file for the neff value
#   4, run merge_cnf to generate the pretag file into the Merge_cnf directory.
#   5, copy all the ss2, newss, pretag, and psp files to the sampler's directory
# example: ./generateCNFPretag.sh T0534_2 1

protein=$1
layer=$2

# TODO: please specify the directory where you have installed BLAST and PSIPRED
export PSIPRED_HOME=~/PSIPRED
export BLASTDB=~/NR/nr
export BLAST_HOME=~/BLAST
export BLASTPGP=$BLAST_HOME/bin/blastpgp
# End of TODO

cd SEQ
if [ ! -e SEQ ]
then
   mkdir SEQ
fi

if [ ! -e PSIPRED-SS ]
then
   mkdir PSIPRED-SS
fi

if [ ! -e HMM ]
then
   mkdir HMM
fi

if [ ! -e Merge_cnf ]
then
   mkdir Merge_cnf
fi

if [ ! -e Merge_crf ]
then
   mkdir Merge_crf
fi

if [ ! -e PSP ]
then
   mkdir PSP
fi

cd ../bin
if [ ! -e ../SEQ/PSP/$protein.psp ]
then
   echo "##RUN BLAST"
   $BLASTPGP -b 0 -j 5 -h 0.001 -d $BLASTDB -i ../SEQ/$protein.seq -C ../SEQ/PSP/$protein.chk -Q ../SEQ/PSP/$protein.psp
fi

if [ ! -e ../SEQ/PSIPRED-SS/$protein.ss2 ]
then
   echo "##RUN_PSIPRED"
  ./runpsipred ../SEQ/$protein.seq; mv $protein.ss $protein.ss2 $protein.horiz ../SEQ/PSIPRED-SS/
fi
./newss.sh $protein ../SEQ/PSIPRED-SS

echo $protein > ../SEQ/list_$protein
if [ $layer -eq 0 ]
then
  ./merge -d ../SEQ -F ../SEQ/list_$protein -M 0
  dest="../SEQ/INPUT_CRF"
  cp ../SEQ/Merge_crf/$protein.* $dest
elif [ $layer -eq 1 ]
then
  ./merge_cnf -d ../SEQ -c 0 -s 1 -m 1 -f ../SEQ/list_$protein
  dest="../SEQ/INPUT_CNF"
  cp ../SEQ/Merge_cnf/$protein.* $dest
else
  if [ ! -e ../SEQ/HMM/$protein.hhm ] 
  then
    ./genA3M.sh ../SEQ/$protein.seq ../SEQ/HMM
  fi
  ./merge_cnf -d ../SEQ -c 1 -m 1 -H 1 -f ../SEQ/list_$protein
  dest="../SEQ/INPUTnoSS"
  cp ../SEQ/Merge_cnf/$protein.* $dest
fi

cp ../SEQ/$protein.* $dest
cp ../SEQ/PSP/$protein.* $dest
cp ../SEQ/PSIPRED-SS/$protein.* $dest

cd ..
